//
// C++ Interface: %{MODULE}
//
// Description: 
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGDOMAINCONSTRAINTSFOLDER_H
#define KPGDOMAINCONSTRAINTSFOLDER_H

#include "kpgitemsfolder.h"

class KPGDomain;


/**
  * Folder for domain constraints
  *
  * @author Lumir Vanek
  */
class KPGDomainConstraintsFolder : public KPGItemsFolder
{
public:
    KPGDomainConstraintsFolder(KPGDomain *);
    ~KPGDomainConstraintsFolder();

    virtual eNodeType type() const { return nodeFolderDomainConstraints; }
    
    // Refresh item, ald also childs objects
	void refresh() throw(const KPGSqlException &);
	
    void refresh(pqxx::oid) throw(const KPGSqlException &);
    
    const pqxx::result & resultConstraints() const { return m_pqxxResultConstraints; }
      
protected:
  	// results that will be displaied in properties window
  	pqxx::result m_pqxxResultConstraints; 
};

#endif
